#
# spec file for package spice-vdagent
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2014 B1 Systems GmbH, Vohburg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           spice-vdagent
Version:        0.17.0
Release:        lp151.3.4
Summary:        Agent for Spice guests
License:        GPL-3.0+
Group:          Applications/System
Url:            http://spice-space.org/
Source0:        http://spice-space.org/download/releases/%{name}-%{version}.tar.bz2
Patch0:         spice-vdagent-var_run.patch
Patch1:         vdagentd-do-endian-swapping.patch
Patch2:         8ba17481-quote-save-dir-before-passing-to-shell.patch
BuildRequires:  alsa-devel  >= 1.0.22
BuildRequires:  desktop-file-utils
BuildRequires:  glib2-devel
BuildRequires:  libXfixes-devel
BuildRequires:  libXinerama-devel
BuildRequires:  libXrandr-devel
BuildRequires:  libpciaccess-devel
BuildRequires:  libtool
BuildRequires:  spice-protocol-devel >= 0.12.8
BuildRequires:  systemd
BuildRequires:  systemd-devel
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(glib-2.0) >= 2.28
Supplements:    modalias(xorg-x11-server:virtio:d00000003v*)
%{?systemd_requires}

%description
Spice agent for Linux guests offering the following features:

Features:
* Client mouse mode (no need to grab mouse by client, no mouse lag)
  this is handled by the daemon by feeding mouse events into the kernel
  via uinput. This will only work if the active X-session is running a
  spice-vdagent process so that its resolution can be determined.
* Automatic adjustment of the X-session resolution to the client resolution
* Support of copy and paste (text and images) between the active X-session
  and the client

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
%configure \
  --with-session-info=systemd \
  --with-init-script=systemd
make %{?_smp_mflags} V=2

%install
make install DESTDIR=%{buildroot} V=2
# move udev role
mv %{buildroot}/lib/udev %{buildroot}%{_prefix}/lib
rmdir %{buildroot}/lib
# remove rsyslogd config
rm -rf %{buildroot}%{_sysconfdir}/rsyslog.d
# create rc symlink
ln -s  service %{buildroot}%{_sbindir}/rcspice-vdagentd

mkdir -p %{buildroot}%{_datadir}/gdm/greeter/autostart

mv %{buildroot}%{_datadir}/gdm/autostart/LoginWindow/*.desktop %{buildroot}%{_datadir}/gdm/greeter/autostart
rm -fr %{buildroot}%{_datadir}/gdm/autostart

%pre
%service_add_pre spice-vdagentd.service
%service_add_pre spice-vdagentd.target

%post
%service_add_post spice-vdagentd.service
if [ "$1" -eq 1 ]; then
    systemctl -q enable spice-vdagentd.service || :
fi
%service_add_post spice-vdagentd.target
%tmpfiles_create %_tmpfilesdir/spice-vdagentd.conf

%preun
%service_del_preun spice-vdagentd.service
%service_del_preun spice-vdagentd.target

%postun
%service_del_postun spice-vdagentd.service
%service_del_postun spice-vdagentd.target

%files
%defattr(-,root,root)
%doc COPYING ChangeLog README TODO
%dir %{_libexecdir}/udev
%dir %{_libexecdir}/udev/rules.d
%{_libexecdir}/udev/rules.d/70-spice-vdagentd.rules
%{_unitdir}/spice-vdagentd.service
%{_unitdir}/spice-vdagentd.target
%{_libexecdir}/tmpfiles.d/spice-vdagentd.conf
%{_bindir}/spice-vdagent
%{_sbindir}/spice-vdagentd
%{_sbindir}/rcspice-vdagentd
%{_sysconfdir}/xdg/autostart/spice-vdagent.desktop
# For /usr/share/gdm/autostart/LoginWindow/spice-vdagent.desktop
# We own the dir too, otherwise we must Require gdm
%{_datadir}/gdm
%{_mandir}/man1/%{name}*.1*

%changelog
* Tue Dec  5 2017 cbosdonnat@suse.com
- Fix potential shell command injection.
  8ba17481-quote-save-dir-before-passing-to-shell.patch
  CVE-2017-15108 (bsc#1070724)
* Thu Jul 27 2017 msuchanek@suse.com
- Fix warning in vdagentd-do-endian-swapping.patch
* Mon Feb 20 2017 msuchanek@suse.com
- Add endian swapping to run on BE guests (boo#1012215).
  vdagentd-do-endian-swapping.patch
* Fri Nov 25 2016 zaitor@opensuse.org
- Add pkgconfig(glib-2.0) BuildRequires: Explicit dependency.
- Handle spice-vdagentd.target in pre/post/preun/postun.
- Handle spice-vdagentd.conf in post via tmpfiles_create macro.
* Fri Nov 25 2016 seife+obs@b1-systems.com
- Update to 0.17.0
  * Denies file-transfer in locked sessions
  * Denies file-transfer in login screen
  * Bump glib version to 2.28
  * Set exit code to 1 instead of 0 when virtio device cannot be
    opened
  * Fix double-free on uinput->screen_info (rhbz#1262635)
  * Code improvement over unix domain client server support (udcs)
  * Fix build compatiblity with different libsystemd versions
    (fdo#94209)
- obsoleted patches removed:
  8c465007-vdagentd-fixes-small-leak.patch
  f97751fa-revert-uinput-fix-small-leak-of-screen_info.patch
- package: add explicit buildrequires for pkgconfig(dbus-1)
* Tue Sep  6 2016 cbosdonnat@suse.com
- Fix crash when changing guest display's resolution (bsc#997236)
  8c465007-vdagentd-fixes-small-leak.patch
  f97751fa-revert-uinput-fix-small-leak-of-screen_info.patch
* Thu Jun  2 2016 cbosdonnat@suse.com
- fate#320079
* Tue Jul 21 2015 mpluskal@suse.com
- Update tp 0.16.0
  * Xspice support
  * Release clipboard on client disconnect if owned by client
    (rhbz#1003977)
  * Turn some error messages into debugging messages (rhbz#918310)
  * Not having the virtio channel is not an error; instead silently
    do nothing
- Cleanup spec file with spec-cleaner
- Actually apply spice-vdagent-var_run.patch
* Wed Jul  9 2014 fcrozat@suse.com
- Add supplements on virtio_console to automatically install
  spice-vdagent when X11 server is installed on KVM with Spice
  enabled.
* Tue Jul  1 2014 fcrozat@suse.com
- Enable systemd service at initial install, it is needed for
  udev rules to properly start the agent.
* Tue May 27 2014 ohering@suse.de
- fix /var/run handling
  spice-vdagent-var_run.patch
* Mon Feb  3 2014 seife+obs@b1-systems.com
- run spec-cleaner
- remove autoreconf call
* Sun Feb  2 2014 seife+obs@b1-systems.com
- import the spec file from fedora core 21, adapt for openSUSE
- version 0.15.0
